==> haskell-syb-0.7.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: syb
version: 0.7.1
id: syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
key: syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
license: BSD-3-Clause
maintainer: Sergey Vinokurov <serg.foo@gmail.com>
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
synopsis: Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.
category: Generics
abi: ee995e1476cc7825cbc506e590fbde37
exposed: True
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins
import-dirs: /usr/lib/ghc-8.6.5/site-local/syb-0.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/syb-0.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/syb-0.7.1
hs-libraries: HSsyb-0.7.1-1gO4OjQOULM8usUjWwwEyW
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html: /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-syb-0.7-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: syb
version: 0.7
id: syb-0.7-KRW1LCxdMiCJrmhxCvzo37
key: syb-0.7-KRW1LCxdMiCJrmhxCvzo37
license: BSD-3-Clause
maintainer: generics@haskell.org
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
synopsis: Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.
category: Generics
abi: dad63e96d42e2b31f489543fa6c6335d
exposed: True
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins
import-dirs: /usr/lib/ghc-8.6.4/site-local/syb-0.7
library-dirs: /usr/lib/ghc-8.6.4/site-local/syb-0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/syb-0.7
hs-libraries: HSsyb-0.7-KRW1LCxdMiCJrmhxCvzo37
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html: /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
